@@ -3,8 +3,8 @@
 ;; Copyright (C) 2025-2026 James Cherti | https://www.jamescherti.com/contact/
 
 ;; Author: James Cherti <https://www.jamescherti.com/contact/>
-;; Package-Version: 20260215.2013
-;; Package-Revision: 067ca5c96faa
+;; Package-Version: 20260217.1345
+;; Package-Revision: 0182193715ea
 ;; URL: https://github.com/jamescherti/kirigami.el
 ;; Keywords: convenience
 ;; Package-Requires: ((emacs "26.3"))
@@ -29,9 +29,10 @@
 ;; closing folds across a diverse set of major and minor modes in Emacs,
 ;; including `treesit-fold-mode', `outline-mode', `outline-minor-mode',
 ;; `outline-indent-minor-mode', `org-mode', `markdown-mode', `gfm-mode',
-;; `vdiff-mode', `vdiff-3way-mode', `hs-minor-mode', `hide-ifdef-mode',
-;; `vimish-fold-mode', `fold-this-mode', `origami-mode', `yafolding-mode',
-;; `folding-mode', and `ts-fold-mode'.
+;; `vdiff-mode', `vdiff-3way-mode', `hs-minor-mode' (hideshow),
+;; `hide-ifdef-mode', `vimish-fold-mode', `TeX-fold-mode' (AUCTeX),
+;; `fold-this-mode', `origami-mode', `yafolding-mode', `folding-mode', and
+;; `ts-fold-mode'.
 ;;
 ;; With Kirigami, folding key bindings only need to be configured once. After
 ;; that, the same keys work consistently across all supported major and minor
@@ -209,6 +210,24 @@ the window constant."
      :open       vimish-fold-unfold
      :open-rec   vimish-fold-unfold
      :close      vimish-fold-refold)
+    ((TeX-fold-mode)
+     :open-all  TeX-fold-clearout-buffer
+     :close-all TeX-fold-buffer
+     :toggle    TeX-fold-dwim  ; Or a lambda calling TeX-fold-item
+     :open      TeX-fold-clearout-item
+     :open-rec  TeX-fold-clearout-item
+     :close     ,(lambda ()
+                   (when (and (fboundp 'TeX-active-mark)
+                              (fboundp 'TeX-fold-item)
+                              (fboundp 'TeX-fold-region)
+                              (fboundp 'TeX-fold-comment)
+                              (cond
+                               ((TeX-active-mark) (TeX-fold-region (mark)
+                                                                   (point)))
+                               ((TeX-fold-item 'macro))
+                               ((TeX-fold-item 'math))
+                               ((TeX-fold-item 'env))
+                               ((TeX-fold-comment)))))))
     ((yafolding-mode)
      :open-all   yafolding-show-all
      :close-all ,(lambda () (save-excursion
@@ -396,18 +415,23 @@ partially scrolled off-screen causes the heading to disappear."
   (if (fboundp 'outline-back-to-heading)
       (save-excursion
         (save-match-data
-          (outline-back-to-heading)
-          (end-of-line)
-          ;; Is it invisible?
-          (cond ((and (bound-and-true-p outline-minor-mode)
-                      (fboundp 'outline-invisible-p))
-                 (funcall 'outline-invisible-p (point)))
+          (condition-case nil
+              (progn (outline-back-to-heading)
+                     (end-of-line)
+                     ;; Is it invisible?
+                     (cond ((and (bound-and-true-p outline-minor-mode)
+                                 (fboundp 'outline-invisible-p))
+                            (funcall 'outline-invisible-p (point)))
 
-                ((and (derived-mode-p 'org-mode)
-                      (fboundp 'org-invisible-p))
-                 (funcall 'org-invisible-p (point)))
+                           ((and (derived-mode-p 'org-mode)
+                                 (fboundp 'org-invisible-p))
+                            (funcall 'org-invisible-p (point)))
 
-                (t (invisible-p (point))))))
+                           (t (invisible-p (point)))))
+            ;; If outline-back-to-heading fails (e.g. before first heading), we
+            ;; assume it is NOT folded.
+            (error
+             nil))))
     (error "Required outline functions are undefined")))
 
 (defun kirigami--outline-legacy-show-entry ()
@@ -474,53 +498,55 @@ the entry is fully visible."
                   (fboundp 'outline-show-children)))
     (error "Required outline functions are undefined"))
 
-  (when (and (fboundp 'outline-on-heading-p)
-             (fboundp 'outline-invisible-p)
-             (fboundp 'outline-back-to-heading)
-             (fboundp 'outline-show-children)
-             (fboundp 'outline-up-heading)
-             (fboundp 'outline-show-children))
-    ;; Workaround for an outline-mode limitation: when jumping via imenu or
-    ;; search, sibling headings above the current one and at the same level
-    ;; often remain hidden. This ensures all sub-items at the current level are
-    ;; revealed, preventing the 'isolated item' effect.
-    (save-excursion
-      ;; Climbing as long as a parent heading exists
-      (catch 'done
-        (while (not (bobp))
-          (condition-case nil
-              (outline-up-heading 1 t)
-            (error
-             (throw 'done t)))
+  ;; Workaround for an outline-mode limitation: when jumping via imenu or
+  ;; search, sibling headings above the current one and at the same level
+  ;; often remain hidden. This ensures all sub-items at the current level are
+  ;; revealed, preventing the 'isolated item' effect.
+  (save-excursion
+    ;; Climbing as long as a parent heading exists
+    (catch 'done
+      (while (not (bobp))
+        (condition-case nil
+            (outline-up-heading 1 t)
+          (error
+           (throw 'done t)))
 
-          (outline-show-children))))
+        (condition-case nil
+            (outline-show-children)
+          (error
+           (throw 'done t))))))
 
-    ;; Repeatedly reveal children and body until the entry is no longer folded
-    (condition-case nil
-        (let ((on-invisible-heading (when (outline-on-heading-p t)
-                                      (outline-invisible-p)))
-              (on-visible-heading (save-excursion
-                                    (beginning-of-line)
-                                    (outline-on-heading-p))))
-          ;; TODO select when (use-region-p)
+  ;; Repeatedly reveal children and body until the entry is no longer folded
+  (condition-case nil
+      (let ((on-invisible-heading (when (outline-on-heading-p t)
+                                    (outline-invisible-p)))
+            (on-visible-heading (save-excursion
+                                  (beginning-of-line)
+                                  (outline-on-heading-p))))
+        ;; TODO select when (use-region-p)
 
-          ;; Repeatedly reveal children and body until the entry is no longer
-          ;; folded
-          (progn
-            (while (kirigami--outline-heading-folded-p)
-              (save-excursion
-                (outline-back-to-heading)
-                (outline-show-children)
-                (kirigami--outline-legacy-show-entry))))
+        ;; Repeatedly reveal children and body until the entry is no longer
+        ;; folded
+        (progn
+          (while (kirigami--outline-heading-folded-p)
+            (save-excursion
+              (outline-back-to-heading)
 
-          ;; If the header was previously hidden, hide the subtree to collapse
-          ;; it. Otherwise, leave the fold open. This allows the user to
-          ;; decide whether to expand the content under the cursor.
-          (when (and on-invisible-heading (not on-visible-heading))
-            (kirigami--outline-legacy-hide-subtree)))
-      ;; `outline-back-to-heading' issue
-      (outline-before-first-heading
-       nil))))
+              ;; Ignore errors here so that if show-children fails, the loop
+              ;; continues and reveals the body text via legacy-show-entry.
+              (ignore-errors
+                (outline-show-children))
+
+              (kirigami--outline-legacy-show-entry))))
+
+        ;; If the header was previously hidden, hide the subtree to collapse
+        ;; it. Otherwise, leave the fold open. This allows the user to
+        ;; decide whether to expand the content under the cursor.
+        (when (and on-invisible-heading (not on-visible-heading))
+          (kirigami--outline-legacy-hide-subtree)))
+    ;; `outline-back-to-heading' issue
+    (outline-before-first-heading
+     nil)))
 
 (defun kirigami--outline-hide-subtree ()
   "Close the current heading's subtree.
